---
title: "HITRUST CSF v11.7"
description: "Terraform compliance scanning for HITRUST CSF v11.7 — assess for free, remediate with ComplyForm"
---

import { Badge } from '@astrojs/starlight/components';

<Badge text="Agency" variant="danger" />
<Badge text="Audit" variant="tip" />

**Issuing body:** [HITRUST Alliance](https://hitrustalliance.net)
**Jurisdiction:** Global — Global
**Countries:** Worldwide


## Assessment

Assess your infrastructure against HITRUST for free at any tier:

```bash
complyform assess --frameworks=hitrust
```

## Remediation

Requires Agency tier or higher ($4,999/yr) for remediation.

```bash
complyform remediate --frameworks=hitrust
```

## Related Frameworks

- [SOC 2 Type II](/frameworks/soc2)
- [CIS GCP v2.0](/frameworks/cis_gcp)
- [CIS Azure v2.0](/frameworks/cis_azure)
- [CIS AWS v3.0](/frameworks/cis_aws)
